import AnimatedElement from "./AnimatedElement";

// Process step interface
interface ProcessStepProps {
  number: number;
  title: string;
  description: string;
  isLast?: boolean;
}

// Process Step component
const ProcessStep = ({ number, title, description, isLast = false }: ProcessStepProps) => (
  <div className="flex group hover:scale-105 transition-transform duration-300">
    <div className="mr-6">
      <div className="flex items-center justify-center w-14 h-14 rounded-full bg-yellow-300 text-black font-bold text-xl shadow-lg group-hover:scale-110 transition-all duration-300">
        {number}
      </div>
      {!isLast && <div className="h-full w-1 bg-gradient-to-b from-yellow-300 to-blue-500/20 mx-auto mt-4 mb-4"></div>}
    </div>
    <div>
      <h3 className="font-heading text-2xl font-bold mb-2 group-hover:text-blue-600 transition-colors duration-300">{title}</h3>
      <p className="text-gray-600 group-hover:text-gray-900 transition-colors duration-300">{description}</p>
    </div>
  </div>
);

export default function Process() {
  // Process steps data
  const processSteps = [
    {
      number: 1,
      title: "Discover",
      description: "We immerse ourselves in your business, understanding your goals, audience, and challenges through research and workshops."
    },
    {
      number: 2,
      title: "Define",
      description: "We translate insights into a clear strategy and roadmap, establishing project objectives and success metrics."
    },
    {
      number: 3,
      title: "Design",
      description: "Our creative team crafts innovative solutions through collaborative ideation, prototyping, and iterative refinement."
    },
    {
      number: 4,
      title: "Deliver",
      description: "We execute with precision, providing ongoing support to ensure successful implementation and measurable results."
    }
  ];

  return (
    <section className="py-20 md:py-28 relative bg-gradient-to-b from-white to-blue-50 overflow-hidden">
      {/* Decorative elements */}
      <div className="absolute top-0 left-10 w-32 h-32 bg-yellow-300 rounded-full blur-3xl opacity-20"></div>
      <div className="absolute bottom-0 right-10 w-48 h-48 bg-blue-400 rounded-full blur-3xl opacity-20"></div>
      <div className="absolute top-40 right-20 w-24 h-24 bg-pink-400 rounded-full blur-2xl opacity-20"></div>
      
      <div className="container mx-auto px-6 relative z-10">
        <AnimatedElement className="text-center max-w-3xl mx-auto mb-16" animation="fade-up">
          <span className="bg-yellow-300 text-black font-bold px-4 py-1 rounded-full inline-block mb-2">How We Work</span>
          <h2 className="font-heading text-3xl md:text-5xl font-bold mt-3 mb-6">Our Design Process</h2>
          <p className="text-gray-600 text-lg">A proven methodology that delivers exceptional results through collaboration and strategic thinking.</p>
        </AnimatedElement>
        
        <div className="grid grid-cols-1 md:grid-cols-2 gap-16 items-center">
          <AnimatedElement className="order-2 md:order-1" animation="fade-up">
            <div className="space-y-12">
              {processSteps.map((step, index) => (
                <ProcessStep 
                  key={step.number}
                  number={step.number}
                  title={step.title}
                  description={step.description}
                  isLast={index === processSteps.length - 1}
                />
              ))}
            </div>
          </AnimatedElement>
          
          <AnimatedElement className="order-1 md:order-2" animation="fade-up" delay={200}>
            <div className="relative group hover:scale-[1.02] transition-all duration-500 cursor-pointer">
              <div className="absolute -inset-4 bg-gradient-to-r from-yellow-300 via-blue-500 to-pink-500 rounded-2xl blur-xl opacity-40 group-hover:opacity-80 transition-all duration-500"></div>
              <div className="relative">
                <img 
                  src="https://images.unsplash.com/photo-1542744173-8e7e53415bb0?ixlib=rb-4.0.3&auto=format&fit=crop&w=870&q=80" 
                  alt="Branding strategy session" 
                  className="rounded-2xl shadow-xl object-cover h-[500px] w-full"
                />
                <div className="absolute inset-0 bg-gradient-to-tr from-blue-600/30 via-transparent to-yellow-300/20 rounded-2xl"></div>
                <div className="absolute bottom-0 left-0 right-0 p-6 bg-gradient-to-t from-black/70 to-transparent rounded-b-2xl">
                  <span className="text-white font-heading font-bold text-xl">Collaborative design sessions</span>
                </div>
              </div>
            </div>
          </AnimatedElement>
        </div>
      </div>
    </section>
  );
}
