import { Star } from "lucide-react";
import AnimatedElement from "./AnimatedElement";

// Testimonial card interface
interface TestimonialCardProps {
  quote: string;
  name: string;
  role: string;
  company: string;
  avatar: string;
  delay?: number;
}

// Testimonial Card component
const TestimonialCard = ({ quote, name, role, company, avatar, delay = 0 }: TestimonialCardProps) => (
  <AnimatedElement 
    className="bg-white p-8 rounded-xl shadow-sm" 
    animation="fade-up"
    delay={delay}
  >
    <div className="flex mb-6">
      {[...Array(5)].map((_, i) => (
        <Star key={i} className="w-5 h-5 fill-yellow-400 text-yellow-400 ml-1 first:ml-0" />
      ))}
    </div>
    <p className="text-muted-foreground italic mb-6">
      "{quote}"
    </p>
    <div className="flex items-center">
      <div className="w-12 h-12 rounded-full bg-neutral-200 overflow-hidden mr-4">
        <img src={avatar} alt={name} className="w-full h-full object-cover" />
      </div>
      <div>
        <p className="font-bold">{name}</p>
        <p className="text-muted-foreground text-sm">{role}, {company}</p>
      </div>
    </div>
  </AnimatedElement>
);

export default function Testimonials() {
  // Testimonials data
  const testimonials = [
    {
      quote: "Burlatech transformed our brand identity and digital presence. Their strategic approach and creative solutions helped us connect with our audience in ways we never thought possible.",
      name: "Sarah Johnson",
      role: "Marketing Director",
      company: "TechVision",
      avatar: "https://randomuser.me/api/portraits/women/45.jpg"
    },
    {
      quote: "Working with Burlatech on our product design was a game-changer. Their team's ability to blend aesthetics with functionality resulted in a product that our customers love.",
      name: "Michael Roberts",
      role: "CEO",
      company: "Innovate Products",
      avatar: "https://randomuser.me/api/portraits/men/32.jpg"
    },
    {
      quote: "The team at Burlatech brings a perfect blend of creativity and strategic thinking. Their work on our website and packaging design has significantly increased our brand recognition.",
      name: "Emma Chen",
      role: "Founder",
      company: "Green Earth",
      avatar: "https://randomuser.me/api/portraits/women/68.jpg"
    }
  ];

  return (
    <section className="py-20 md:py-28 bg-neutral-100">
      <div className="container mx-auto px-6">
        <AnimatedElement className="text-center max-w-3xl mx-auto mb-16" animation="fade-up">
          <span className="text-secondary font-medium">Client Testimonials</span>
          <h2 className="font-heading text-3xl md:text-4xl font-bold mt-3 mb-6">What Our Clients Say</h2>
          <p className="text-muted-foreground">Don't just take our word for it—hear what our clients have to say about working with Burlatech.</p>
        </AnimatedElement>
        
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {testimonials.map((testimonial, index) => (
            <TestimonialCard 
              key={testimonial.name}
              quote={testimonial.quote}
              name={testimonial.name}
              role={testimonial.role}
              company={testimonial.company}
              avatar={testimonial.avatar}
              delay={index * 100} // Stagger animations
            />
          ))}
        </div>
      </div>
    </section>
  );
}
