import { Link } from 'wouter';
import { ArrowLeft } from 'lucide-react';
import { Button } from '@/components/ui/button';

export default function CookiesPolicy() {
  return (
    <div className="bg-white py-20">
      <div className="container mx-auto px-6">
        <div className="mb-8">
          <Button
            variant="ghost"
            className="flex items-center text-gray-600 hover:text-blue-600"
            asChild
          >
            <Link href="/">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Back to Home
            </Link>
          </Button>
        </div>
        
        <div className="max-w-4xl mx-auto">
          <div className="mb-12">
            <span className="bg-yellow-300 text-black font-bold px-4 py-1 rounded-full inline-block mb-4">Legal</span>
            <h1 className="font-heading text-4xl md:text-5xl font-bold mb-6">Cookies Policy</h1>
            <p className="text-gray-600 text-lg">Last Updated: May 2025</p>
          </div>
          
          <div className="prose prose-lg max-w-none">
            <p>
              At Burlatech, we use cookies and similar technologies to enhance your browsing experience, analyze site traffic, and personalize content. This Cookies Policy explains how we use these technologies when you visit our website.
            </p>
            
            <h2>What Are Cookies?</h2>
            <p>
              Cookies are small text files that are stored on your device when you visit a website. They help websites remember information about your visit, such as your preferred language and other settings. This makes your next visit easier and the site more useful to you.
            </p>
            
            <h2>Types of Cookies We Use</h2>
            <p>We use the following types of cookies on our website:</p>
            
            <h3>Essential Cookies</h3>
            <p>
              These cookies are necessary for the website to function properly. They enable core functionality such as security, network management, and account access. You cannot opt out of these cookies.
            </p>
            
            <h3>Analytics Cookies</h3>
            <p>
              These cookies help us understand how visitors interact with our website by collecting and reporting information anonymously. They help us improve the performance and design of our website.
            </p>
            
            <h3>Functional Cookies</h3>
            <p>
              These cookies enable enhanced functionality and personalization, such as videos and live chat. They may be set by us or by third-party providers whose services we have added to our pages. If you disable these cookies, some or all of these features may not function properly.
            </p>
            
            <h3>Marketing Cookies</h3>
            <p>
              These cookies are used to track visitors across websites. They are set to display targeted advertisements based on your interests and online behavior. They also help measure the effectiveness of advertising campaigns.
            </p>
            
            <h2>Third-Party Cookies</h2>
            <p>
              Some cookies are placed by third parties on our website. These third parties may include analytics providers (like Google Analytics), advertising networks, and social media platforms. These third parties may use cookies, web beacons, and similar technologies to collect or receive information from our website and elsewhere on the internet to provide measurement services and target ads.
            </p>
            
            <h2>How We Use Cookies</h2>
            <p>We use cookies for various purposes, including:</p>
            <ul>
              <li>Remembering your preferences and settings</li>
              <li>Understanding how you use our website</li>
              <li>Improving the performance and user experience of our website</li>
              <li>Providing personalized content and advertising</li>
              <li>Monitoring the effectiveness of our marketing campaigns</li>
              <li>Preventing fraud and enhancing security</li>
            </ul>
            
            <h2>Cookie Management</h2>
            <p>
              Most web browsers allow you to control cookies through their settings. You can usually find these settings in the "Options" or "Preferences" menu of your browser. You can delete existing cookies, allow or block all cookies, or block cookies from particular sites.
            </p>
            <p>
              Please note that blocking or deleting cookies may impact your experience on our website, as some features may not function properly.
            </p>
            
            <h2>Browser-Specific Instructions</h2>
            <p>For information on managing cookies in specific browsers, please visit:</p>
            <ul>
              <li><a href="https://support.google.com/chrome/answer/95647" target="_blank" rel="noopener noreferrer">Google Chrome</a></li>
              <li><a href="https://support.mozilla.org/en-US/kb/enhanced-tracking-protection-firefox-desktop" target="_blank" rel="noopener noreferrer">Mozilla Firefox</a></li>
              <li><a href="https://support.apple.com/guide/safari/manage-cookies-sfri11471/mac" target="_blank" rel="noopener noreferrer">Safari</a></li>
              <li><a href="https://support.microsoft.com/en-us/windows/microsoft-edge-browsing-data-and-privacy-bb8174ba-9d73-dcf2-9b4a-c582b4e640dd" target="_blank" rel="noopener noreferrer">Microsoft Edge</a></li>
            </ul>
            
            <h2>Changes to This Cookies Policy</h2>
            <p>
              We may update our Cookies Policy from time to time. We will notify you of any changes by posting the new Cookies Policy on this page and updating the "Last Updated" date.
            </p>
            
            <h2>Contact Us</h2>
            <p>
              If you have questions or concerns about this Cookies Policy, please contact us at:
            </p>
            <p>
              Burlatech<br />
              Email: privacy@burlatech.com<br />
              Phone: +1 (555) 234-5678
            </p>
            
            <div className="bg-blue-50 p-6 rounded-lg mt-8">
              <h3 className="text-xl font-bold mb-4">Cookie Consent</h3>
              <p>
                By continuing to use our website, you consent to the use of cookies as described in this Cookies Policy. You can change your cookie settings at any time through your browser settings.
              </p>
              <Button 
                className="mt-4 bg-blue-600 hover:bg-blue-700 text-white font-medium py-2 px-4 rounded-md"
              >
                I Understand
              </Button>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}
