import { Link } from 'wouter';
import { ArrowLeft } from 'lucide-react';
import { Button } from '@/components/ui/button';

export default function PrivacyPolicy() {
  return (
    <div className="bg-white py-20">
      <div className="container mx-auto px-6">
        <div className="mb-8">
          <Button
            variant="ghost"
            className="flex items-center text-gray-600 hover:text-blue-600"
            asChild
          >
            <Link href="/">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Back to Home
            </Link>
          </Button>
        </div>
        
        <div className="max-w-4xl mx-auto">
          <div className="mb-12">
            <span className="bg-yellow-300 text-black font-bold px-4 py-1 rounded-full inline-block mb-4">Legal</span>
            <h1 className="font-heading text-4xl md:text-5xl font-bold mb-6">Privacy Policy</h1>
            <p className="text-gray-600 text-lg">Last Updated: May 2025</p>
          </div>
          
          <div className="prose prose-lg max-w-none">
            <p>
              At Burlatech, we respect your privacy and are committed to protecting your personal data. This Privacy Policy explains how we collect, use, and safeguard your information when you visit our website or engage with our services.
            </p>
            
            <h2>Information We Collect</h2>
            <p>
              We may collect several types of information from and about users of our website, including:
            </p>
            <ul>
              <li><strong>Personal Information:</strong> Name, email address, phone number, company name, and other contact details you provide when filling out forms on our website.</li>
              <li><strong>Usage Data:</strong> Information about how you interact with our website, including browsing actions, patterns, page response times, and other statistical data.</li>
              <li><strong>Technical Data:</strong> IP address, browser type and version, time zone setting, operating system, and platform.</li>
              <li><strong>Marketing Preferences:</strong> Your preferences in receiving marketing communications from us.</li>
            </ul>
            
            <h2>How We Use Your Information</h2>
            <p>We use the information we collect to:</p>
            <ul>
              <li>Provide, maintain, and improve our services and website</li>
              <li>Process and fulfill your requests, inquiries, or orders</li>
              <li>Communicate with you about our services, events, and other news</li>
              <li>Understand how users interact with our website to enhance user experience</li>
              <li>Develop new products, services, and features</li>
              <li>Prevent fraud and enhance the security of our website</li>
            </ul>
            
            <h2>Information Sharing</h2>
            <p>
              We do not sell or rent your personal information to third parties. We may share your information with:
            </p>
            <ul>
              <li><strong>Service Providers:</strong> Third-party vendors who assist us in operating our website, conducting our business, or providing services to you.</li>
              <li><strong>Business Partners:</strong> With your consent, we may share your information with our business partners to offer you certain products, services, or promotions.</li>
              <li><strong>Legal Compliance:</strong> We may disclose information if required by law or in response to valid requests by public authorities.</li>
            </ul>
            
            <h2>Your Rights</h2>
            <p>Depending on your location, you may have certain rights regarding your personal information, including:</p>
            <ul>
              <li>The right to access your personal information</li>
              <li>The right to rectify inaccurate information</li>
              <li>The right to request erasure of your information</li>
              <li>The right to restrict or object to processing</li>
              <li>The right to data portability</li>
              <li>The right to withdraw consent</li>
            </ul>
            
            <h2>Data Security</h2>
            <p>
              We implement appropriate security measures to protect your personal information from unauthorized access, alteration, disclosure, or destruction. However, no method of transmission over the Internet or electronic storage is 100% secure, and we cannot guarantee absolute security.
            </p>
            
            <h2>International Transfers</h2>
            <p>
              As a global creative agency, your information may be transferred to and processed in countries other than your own. We take steps to ensure that your information receives an adequate level of protection wherever it is processed.
            </p>
            
            <h2>Children's Privacy</h2>
            <p>
              Our website is not intended for children under 16 years of age. We do not knowingly collect personal information from children under 16. If you are a parent or guardian and believe your child has provided us with personal information, please contact us.
            </p>
            
            <h2>Changes to This Privacy Policy</h2>
            <p>
              We may update our Privacy Policy from time to time. We will notify you of any changes by posting the new Privacy Policy on this page and updating the "Last Updated" date at the top of this page.
            </p>
            
            <h2>Contact Us</h2>
            <p>
              If you have questions or concerns about this Privacy Policy, please contact us at:
            </p>
            <p>
              Burlatech<br />
              Email: privacy@burlatech.com<br />
              Phone: +1 (555) 234-5678
            </p>
          </div>
        </div>
      </div>
    </div>
  );
}
