import { Link } from 'wouter';
import { ArrowLeft } from 'lucide-react';
import { Button } from '@/components/ui/button';

export default function TermsOfService() {
  return (
    <div className="bg-white py-20">
      <div className="container mx-auto px-6">
        <div className="mb-8">
          <Button
            variant="ghost"
            className="flex items-center text-gray-600 hover:text-blue-600"
            asChild
          >
            <Link href="/">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Back to Home
            </Link>
          </Button>
        </div>
        
        <div className="max-w-4xl mx-auto">
          <div className="mb-12">
            <span className="bg-yellow-300 text-black font-bold px-4 py-1 rounded-full inline-block mb-4">Legal</span>
            <h1 className="font-heading text-4xl md:text-5xl font-bold mb-6">Terms of Service</h1>
            <p className="text-gray-600 text-lg">Last Updated: May 2025</p>
          </div>
          
          <div className="prose prose-lg max-w-none">
            <p>
              Welcome to Burlatech. These Terms of Service ("Terms") govern your use of our website and services. By accessing or using our website, you agree to be bound by these Terms.
            </p>
            
            <h2>Our Services</h2>
            <p>
              Burlatech is a multidisciplinary design and branding agency providing strategy, innovation, branding, and design services to businesses. Our services include but are not limited to:
            </p>
            <ul>
              <li>Brand strategy and development</li>
              <li>Visual identity design</li>
              <li>Digital product design</li>
              <li>Communication and marketing design</li>
              <li>Experience and service design</li>
              <li>Packaging design</li>
              <li>Web and app design</li>
            </ul>
            
            <h2>Project Engagements</h2>
            <p>
              All project engagements are governed by separate agreements that detail the scope of work, deliverables, timelines, and payment terms. These Terms supplement any project-specific agreements we may have with you.
            </p>
            
            <h2>Intellectual Property Rights</h2>
            <p>
              <strong>Our Content:</strong> All content on our website, including text, graphics, logos, images, and software, is the property of Burlatech or our licensors and is protected by copyright, trademark, and other intellectual property laws.
            </p>
            <p>
              <strong>Client Materials:</strong> You retain ownership of any materials you provide to us for project work. By sharing content with us, you grant us a non-exclusive, worldwide, royalty-free license to use, reproduce, and modify that content solely for the purpose of providing our services to you.
            </p>
            <p>
              <strong>Deliverables:</strong> Upon full payment for our services, you will receive rights to the final deliverables as specified in your project agreement. Unless otherwise agreed, we retain the right to use the work for our portfolio and promotional purposes.
            </p>
            
            <h2>Use of Our Website</h2>
            <p>You agree not to:</p>
            <ul>
              <li>Use our website in any way that violates applicable laws or regulations</li>
              <li>Attempt to gain unauthorized access to any portion of our website</li>
              <li>Use our website to distribute malware, viruses, or other malicious code</li>
              <li>Scrape, harvest, or extract data from our website without our written permission</li>
              <li>Use our website in a way that could damage, disable, or impair its functioning</li>
            </ul>
            
            <h2>Confidentiality</h2>
            <p>
              We respect the confidentiality of information you share with us. We will not disclose your confidential information to third parties without your permission, except as required by law or as necessary to provide our services.
            </p>
            
            <h2>Feedback and Submissions</h2>
            <p>
              By submitting ideas, suggestions, or feedback about our services, you grant us a perpetual, irrevocable, worldwide, royalty-free license to use, modify, publicly perform, publicly display, reproduce, and distribute those submissions for any purpose.
            </p>
            
            <h2>Limitation of Liability</h2>
            <p>
              To the maximum extent permitted by law, Burlatech and its directors, employees, and agents will not be liable for any indirect, incidental, special, consequential, or punitive damages arising out of or relating to your use of our website or services.
            </p>
            
            <h2>Disclaimers</h2>
            <p>
              Our website and services are provided on an "as is" and "as available" basis without warranties of any kind, either express or implied. We do not warrant that our website will be uninterrupted, error-free, or free of viruses or other harmful components.
            </p>
            
            <h2>Termination</h2>
            <p>
              We may terminate or suspend your access to our website immediately, without prior notice or liability, for any reason, including if you breach these Terms.
            </p>
            
            <h2>Changes to These Terms</h2>
            <p>
              We may update these Terms from time to time. We will notify you of any changes by posting the updated Terms on this page. Your continued use of our website after any changes constitutes your acceptance of the revised Terms.
            </p>
            
            <h2>Governing Law</h2>
            <p>
              These Terms are governed by and construed in accordance with the laws of the jurisdiction where Burlatech is registered, without regard to its conflict of law principles.
            </p>
            
            <h2>Contact Us</h2>
            <p>
              If you have questions or concerns about these Terms, please contact us at:
            </p>
            <p>
              Burlatech<br />
              Email: legal@burlatech.com<br />
              Phone: +1 (555) 234-5678
            </p>
          </div>
        </div>
      </div>
    </div>
  );
}
